import re
import urllib
import cgi
from dosage.modules.helpers.BasicComicModule import BasicComicModule
from dosage.modules.helpers.BasicComicModule import BounceMixin
from dosage.util import getQueryParams

class PiledHigherAndDeeper(BasicComicModule, BounceMixin):
    baseUrl = 'http://www.phdcomics.com/comics/archive.php'
    imageUrl = 'http://www.phdcomics.com/comics/archive.php?comicid=%s'
    imageSearch = re.compile(r'<img src=(http://www\.phdcomics\.com/comics/archive/phd\d+s?\.gif) border=5 align=top>')
    prevSearch = re.compile(r'<a href=(archive\.php\?comicid=\d+)><img height=52 width=49 src=images/prev_button\.gif border=0 align=middle>')
    nextSearch = re.compile(r'<a href=(archive\.php\?comicid=\d+)><img height=52 width=49 src=images/next_button\.gif border=0 align=middle>')
    help = 'Index format: n (unpadded)'

    def getFilename(self, imageUrl, pageUrl):
        return getQueryParams(pageUrl)['comicid'][0]
